==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/lv.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Nepareiza glabātuve",
    "Unknown error" : "Nezināma kļūda",
    "Files" : "Datnes",
    "All files" : "Visas datnes",
    "Recent" : "Nesenās",
    "File could not be found" : "Datni nevar atrast",
    "Home" : "Mājas",
    "Close" : "Aizvērt",
    "Favorites" : "Iecienītie",
    "Could not create folder \"{dir}\"" : "Nevarēja izveidot mapi \"{dir}\"",
    "Upload cancelled." : "Augšupielāde ir atcelta.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturoša datne.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
    "Uploading..." : "Augšupielādē...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} no {totalSize} ({bitrate})",
    "Actions" : "Darbības",
    "Download" : "Lejupielādēt",
    "Rename" : "Pārsaukt",
    "Delete" : "Dzēst",
    "Disconnect storage" : "Atvienot glabātuvi",
    "Unshare" : "Pārtraukt koplietošanu",
    "Details" : "Detaļas",
    "Select" : "Norādīt",
    "Pending" : "Gaida savu kārtu",
    "Unable to determine date" : "Neizdevās noteikt datumu",
    "This operation is forbidden" : "Šī darbība ir aizliegta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
    "Could not move \"{file}\", target exists" : "Nevarēja pārvietot \"{file}\", mērķis eksistē",
    "Could not move \"{file}\"" : "Nevarēja pārvietot \"{file}\"",
    "{newName} already exists" : "{newName} jau eksistē",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nevarēja pārsaukt \"{fileName}\", tā vairs neeksistē",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nosaukums \"{targetName}\" jau tiek izmantots mapē \"{dir}\". Lūdzu izvēlies citu nosaukumu.",
    "Could not rename \"{fileName}\"" : "Nevarēja pārsaukt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nevarēja izveidot datni \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nevarēja izveidot datni \"{file}\", jo tā jau eksistē",
    "Could not create folder \"{dir}\" because it already exists" : "Nevarēja izveidot mapi \"{dir}\", jo tā jau eksistē",
    "Error deleting file \"{fileName}\"." : "Kļūda dzēšot datni \"{fileName}\".",
    "Name" : "Nosaukums",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "_%n file_::_%n files_" : ["%n datnes","%n datne","%n datnes"],
    "{dirs} and {files}" : "{dirs} un {files}",
    "You don’t have permission to upload or create files here" : "Jums nav tiesību šeit augšupielādēt vai veidot datnes",
    "_Uploading %n file_::_Uploading %n files_" : ["%n","Augšupielāde %n failu","Augšupielādē %n datnes"],
    "New" : "Jauna",
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} glabātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsu glabātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atrasts pēc '{filter}'","atrasts pēc '{filter}'","atrasti pēc '{filter}'"],
    "View in folder" : "Skatīt mapē",
    "Path" : "Ceļš",
    "_%n byte_::_%n bytes_" : ["%n baiti","%n baits","%n baiti"],
    "Favorited" : "Favorīti",
    "Favorite" : "Iecienītais",
    "Folder" : "Mape",
    "New folder" : "Jauna mape",
    "Upload" : "Augšupielādēt",
    "An error occurred while trying to update the tags" : "Notika kļūda atjaunojot atzīmi",
    "A new file or folder has been <strong>created</strong>" : "<strong>Izveidota</strong> jauna datne vai mape",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitēt ziņojumus par jūsu <strong>iecienīto datņu</strong> izveidošanu un izmaiņām <em>(tikai datu straumei)</em>",
    "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
    "File handling" : "Datņu pārvaldība",
    "Maximum upload size" : "Maksimālais datņu augšupielādes apjoms",
    "max. possible: " : "maksimālais iespējamais:",
    "Save" : "Saglabāt",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Ar PHP-FPM var aizņemt 5 minūtes, kamēr izmaiņas stāsies spēkā.",
    "Missing permissions to edit from here." : "Nepietiekamas tiesības lai rediģētu no šejienes.",
    "Settings" : "Iestatījumi",
    "Show hidden files" : "Rādīt slēptās datnes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Izmanto šo adresi, lai <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">sasniegtu savas datnes caur WebDAV</a>",
    "No files in here" : "Šeit nav datņu",
    "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Select all" : "Atzīmēt visu",
    "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
    "No favorites" : "Nav favorītu",
    "Files and folders you mark as favorite will show up here" : "Datnes un mapes, ko atzīmēsiet kā favorītus, tiks rādīti šeit",
    "Text file" : "Teksta datne",
    "New text file.txt" : "Jauna teksta datne.txt",
    "Storage not available" : "Glabātuve nav pieejama",
    "Unable to set upload directory." : "Nevar uzstādīt augšupielādes mapi.",
    "Invalid Token" : "Nepareiza pilnvara",
    "No file was uploaded. Unknown error" : "Netika augšupielādēta neviena datne. Nezināma kļūda",
    "There is no error, the file uploaded with success" : "Viss kārtībā, datne augšupielādēta veiksmīga",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Augšupielādētā datne pārsniedz upload_max_filesize norādījumu php.ini datnē:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
    "The uploaded file was only partially uploaded" : "Augšupielādētā datne ir tikai daļēji augšupielādēta",
    "No file was uploaded" : "Neviena datne netika augšupielādēta",
    "Missing a temporary folder" : "Trūkst pagaidu mapes",
    "Failed to write to disk" : "Neizdevās saglabāt diskā",
    "Not enough storage available" : "Nav pietiekami daudz vietas",
    "The target folder has been moved or deleted." : "Mērķa mape ir pārvietota vai dzēsta",
    "Upload failed. Could not find uploaded file" : "Augšupielāde nesekmīga. Nevarēja atrast augšupielādēto datni.",
    "Upload failed. Could not get file info." : "Augšupielāde nesekmīga. Nevarēja iegūt informāciju par datni.",
    "Invalid directory." : "Nederīga direktorija.",
    "Total file size {size1} exceeds upload limit {size2}" : "Kopējais datnes izmērs {size1} pārsniedz augšupielādes ierobežojumu {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Kļūda augšupielādējot datni \"{fileName}\": {message}",
    "Could not get result from server." : "Nevar saņemt rezultātus no servera",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} stunda{plural_s} atlicis",
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minūte{plural_s} atlicis",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "{seconds} second{plural_s} left" : "{seconds} sekunde{plural_s} atlicis",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Jebkurā brīdī tagad...",
    "Soon..." : "Drīz...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Notiek augšupielāde. Pametot lapu tagad, tiks atcelta augšupielāde.",
    "No entries in this folder match '{filter}'" : "Šajā mapē nekas nav atrasts, meklējot pēc '{filter}'",
    "Local link" : "Lokāla saite",
    "{newname} already exists" : "{newname} jau eksistē",
    "A file or folder has been <strong>changed</strong>" : "<strong>Izmainīta</strong> datne vai mape",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Dzēsta</strong> datne vai mape",
    "A file or folder has been <strong>restored</strong>" : "<strong>Atjaunota</strong> datne vai mape",
    "You created %1$s" : "Tu izveidoji %1$s",
    "%2$s created %1$s" : "%2$s izveidoja %1$s",
    "%1$s was created in a public folder" : "%1$s tika izveidots publiskajā mapē",
    "You changed %1$s" : "Tu izmainīji %1$s",
    "%2$s changed %1$s" : "%2$s izmainīja %1$s",
    "You deleted %1$s" : "Tu izdzēsi %1$s",
    "%2$s deleted %1$s" : "%2$s izdzēsa %1$s",
    "You restored %1$s" : "Tu atjaunoji %1$s",
    "%2$s restored %1$s" : "%2$s atjaunoja %1$s",
    "Changed by %2$s" : "Izmainīja %2$s",
    "Deleted by %2$s" : "Dzēsa %2$s",
    "Restored by %2$s" : "Atjaunoja %2$s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/lv.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
    "Storage invalid" : "Nepareiza glabātuve",
    "Unknown error" : "Nezināma kļūda",
    "All files" : "Visas datnes",
    "Recent" : "Nesenās",
    "File could not be found" : "Datni nevar atrast",
    "Home" : "Mājas",
    "Close" : "Aizvērt",
    "Favorites" : "Iecienītie",
    "Could not create folder \"{dir}\"" : "Nevarēja izveidot mapi \"{dir}\"",
    "Upload cancelled." : "Augšupielāde ir atcelta.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturoša datne.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Mape \"{dir}\" vairs neeksistē",
    "Not enough free space" : "Nav pietiekami daudz brīvas vietas",
    "Uploading..." : "Augšupielādē...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} no {totalSize} ({bitrate})",
    "Actions" : "Darbības",
    "Download" : "Lejupielādēt",
    "Rename" : "Pārsaukt",
    "Move" : "Pārvietot",
    "Target folder" : "Mērķa mape",
    "Delete" : "Dzēst",
    "Disconnect storage" : "Atvienot glabātuvi",
    "Unshare" : "Pārtraukt koplietošanu",
    "Could not load info for file \"{file}\"" : "Nevar ielādēt informāciju par failu \"{file}\"",
    "Files" : "Datnes",
    "Details" : "Detaļas",
    "Select" : "Norādīt",
    "Pending" : "Gaida savu kārtu",
    "Unable to determine date" : "Neizdevās noteikt datumu",
    "This operation is forbidden" : "Šī darbība ir aizliegta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
    "Could not move \"{file}\", target exists" : "Nevarēja pārvietot \"{file}\", mērķis eksistē",
    "Could not move \"{file}\"" : "Nevarēja pārvietot \"{file}\"",
    "{newName} already exists" : "{newName} jau eksistē",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nevarēja pārsaukt \"{fileName}\", tā vairs neeksistē",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nosaukums \"{targetName}\" jau tiek izmantots mapē \"{dir}\". Lūdzu izvēlies citu nosaukumu.",
    "Could not rename \"{fileName}\"" : "Nevarēja pārsaukt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nevarēja izveidot datni \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nevarēja izveidot datni \"{file}\", jo tā jau eksistē",
    "Could not create folder \"{dir}\" because it already exists" : "Nevarēja izveidot mapi \"{dir}\", jo tā jau eksistē",
    "Error deleting file \"{fileName}\"." : "Kļūda dzēšot datni \"{fileName}\".",
    "Name" : "Nosaukums",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "_%n file_::_%n files_" : ["%n datnes","%n datne","%n datnes"],
    "{dirs} and {files}" : "{dirs} un {files}",
    "_including %n hidden_::_including %n hidden_" : ["ieskaitot %n paslēptos","ieskaitot %n paslēptos","ieskaitot %n paslēptos"],
    "You don’t have permission to upload or create files here" : "Jums nav tiesību šeit augšupielādēt vai veidot datnes",
    "_Uploading %n file_::_Uploading %n files_" : ["%n","Augšupielāde %n failu","Augšupielādē %n datnes"],
    "New" : "Jauna",
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} glabātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsu glabātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atrasts pēc '{filter}'","atrasts pēc '{filter}'","atrasti pēc '{filter}'"],
    "View in folder" : "Skatīt mapē",
    "Path" : "Ceļš",
    "_%n byte_::_%n bytes_" : ["%n baiti","%n baits","%n baiti"],
    "Favorited" : "Favorīti",
    "Favorite" : "Iecienītais",
    "New folder" : "Jauna mape",
    "An error occurred while trying to update the tags" : "Notika kļūda atjaunojot atzīmi",
    "Added to favorites" : "Pievienot izlasei",
    "Removed from favorites" : "Noņemt no izlases",
    "You added {file} to your favorites" : "Pievienoji {file} savai izlasei",
    "You removed {file} from your favorites" : "Noņēmi {file} no savas izlases",
    "File changes" : "Faila izmaiņas",
    "Created by {user}" : "Izveidoja {user}",
    "Changed by {user}" : "Izmainīja {user}",
    "Deleted by {user}" : "Dzēsa {user}",
    "Restored by {user}" : "Atjaunoja {user}",
    "Renamed by {user}" : "Pārdēvēja {user}",
    "Moved by {user}" : "Pārvietoja {user}",
    "You created {file}" : "Izveidoji {file}",
    "{user} created {file}" : "{user} izveidoja {file}",
    "{file} was created in a public folder" : "{file} tika izveidots publiskajā mapē",
    "You changed {file}" : "Izmainīji {file}",
    "{user} changed {file}" : "{user} mainīts {file}",
    "You deleted {file}" : "Tu izdzēsi {file}",
    "{user} deleted {file}" : "{user} izdzēsa {file}",
    "You restored {file}" : "Tu atjaunoji {file}",
    "{user} restored {file}" : "{user} atjaunoja {file}",
    "You renamed {oldfile} to {newfile}" : "Pārdēvēji {oldfile} uz {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} pārdēvēja {oldfile} uz {newfile}",
    "You moved {oldfile} to {newfile}" : "Pārvietoji {oldfile} uz {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} pārvietoja {oldfile} uz {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Fails ir pievienots vai noņemts no jūsu <strong>izlases</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Fails vai mape tika <strong>mainīts</strong> vai <strong>pārsaukts</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>Izveidota</strong> jauna datne vai mape",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitēt ziņojumus par jūsu <strong>iecienīto datņu</strong> izveidošanu un izmaiņām <em>(tikai datu straumei)</em>",
    "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
    "File handling" : "Datņu pārvaldība",
    "Maximum upload size" : "Maksimālais datņu augšupielādes apjoms",
    "max. possible: " : "maksimālais iespējamais:",
    "Save" : "Saglabāt",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Ar PHP-FPM var aizņemt 5 minūtes, kamēr izmaiņas stāsies spēkā.",
    "Missing permissions to edit from here." : "Nepietiekamas tiesības lai rediģētu no šejienes.",
    "Settings" : "Iestatījumi",
    "Show hidden files" : "Rādīt slēptās datnes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Izmanto šo adresi, lai <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">sasniegtu savas datnes caur WebDAV</a>",
    "No files in here" : "Šeit nav datņu",
    "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Select all" : "Atzīmēt visu",
    "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
    "Files and folders you mark as favorite will show up here" : "Datnes un mapes, ko atzīmēsiet kā favorītus, tiks rādīti šeit",
    "Shared with you" : "Koplietots ar tevi",
    "Shared with others" : "Koplietots ar citiem",
    "Shared by link" : "Koplietots ar saiti",
    "Tags" : "Atzīmes",
    "Deleted files" : "Dzēstās datnes",
    "Text file" : "Teksta datne",
    "New text file.txt" : "Jauna teksta datne.txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} stundas atlicis","{hours}:{minutes}:{seconds} stundas atlicis","{hours}:{minutes}:{seconds} stundas atlikušas"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} minūtes atlikušas","{minutes}:{seconds} minūtes atlikušas","{minutes}:{seconds} minūtes atlikušas"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} sekundes atlikušas","{seconds} sekundes atlikušas","{seconds} sekundes atlikušas"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Jebkurā brīdī tagad...",
    "Soon..." : "Drīz...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Notiek augšupielāde. Pametot lapu tagad, tiks atcelta augšupielāde.",
    "Copy local link" : "Kopēt lokālo saiti",
    "Folder" : "Mape",
    "Upload" : "Augšupielādēt",
    "A new file or folder has been <strong>deleted</strong>" : "Fails vai mape tika <strong>dzēsts</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Fails vai mape tika <strong>atjaunots</strong>",
    "No favorites" : "Nav favorītu"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
